""" Various utilities """
from typing import List

def split_symbol(symbol: str) -> (str, str):
    """ Splits the symbol into namespace, symbol tuple """
    symbol_parts = symbol.split(":")
    namespace = None
    mnemonic = symbol

    if len(symbol_parts) > 1:
        namespace = symbol_parts[0]
        mnemonic = symbol_parts[1]

    return (namespace, mnemonic)

def read_lines_from_file(file_path: str) -> List[str]:
    """ Read text lines from a file """
    # check if the file exists?
    with open(file_path) as csv_file:
        content = csv_file.readlines()
    return content
    


""" Domain model. Public """
from decimal import Decimal
from datetime import datetime


class PriceModel:
    """ The price element """
    def __init__(self):
        self.datetime: datetime = None
        self.namespace: str = None
        self.symbol: str = None
        self.value: Decimal = Decimal(0)
        self.currency: str = None

    def __repr__(self):
        symbol = f"{self.namespace}:{self.symbol}" if self.namespace else self.symbol
        symbol = f"{symbol:<13}"

        value = f"{self.value:>6}"
        return f"<Price ('{symbol}',date:{self.datetime},value:{value},currency:{self.currency})>"
